##############################################
###           Gnralites sur R           ###
##############################################

#####################
### Ouvrir un fichier de donnees

data <- read.csv2("myData.csv",na.string="")


#####################
### Voir les donnes

# Toutes les donnes
data

# Rsum des donnes
summary(data)

# Type des donnes
str(data)

# Nom des donnes
names(data)


#####################
### Selection d'une partie des donnes

# Ligne 3
data[3,]

# Lignes 3  5
data[3:5,]

# Lignes 2, 4 et 6
data[c(2,4,6),]

# Colonne 4
data[,4]

# Colonnes 4 et 6
data[,c(4,6)]

# Colonne 'id'
data$id

# Colonne 5 ligne 4
data[4,5]


#####################
### Obtenir de l'aide

?summary




##############################################
###                  KmL                   ###
##############################################

#####################
### Charger un package

# Rapatrier le package localement
# Charger le package dans R
library(kml)
?kml


#####################
### Prparer les donnes

### Exemple simple
# Lire le fichier
data1 <- read.csv2("myLongData1.csv")

# Prparer l'objet cld
myCld1 <- as.cld(data1)

# Afficher l'objet cld
plot(myCld1)


### Exemple moins simple
# Lire le fichier
data2 <- read.csv2("myLongData2.csv")

# Prparer l'objet cld
myCld2 <- as.cld(data2,timeCol=c(2,4,6,8,9),timeReal=c(5,13,24,41,54),varName="hourPerDay")

# Afficher l'objet cld
plot(myCld2)


### Exemple rel
# Lire le fichier
data3 <- read.csv2("paquid800.csv")

# Prparer l'objet cld
myCld3 <- as.cld(data3,timeCol=76:83,timeReal=c(0,1,3,5,8,10,13,15))

# Afficher l'objet cld
plot(myCld3)


#####################
### Clusteriser les donnes

### Exemple simple
# 4 clusters, un seul tirage
kml(myCld2,nbClusters=4,nbRedrawing=1,print.traj=TRUE)

# 2, 3, 5 clusters, un seul tirage pour chaque
kml(myCld2,nbClusters=c(2,3,5),nbRedrawing=1,print.traj=TRUE)

# 4 clusters, 5 tirages
kml(myCld2,nbClusters=4,nbRedrawing=5,print.traj=TRUE)

# Par dfaut, 2,3,4,5,6 clusters et 20 tirages
kml(myCld2,print.traj=TRUE)

# Le meme en rapide
kml(myCld2)

# Afficher l'objet cld
plot(myCld2)

# Afficher l'objet cld avec 3 clusters
plot(myCld2,3)



### Exemple rel
# Avec affichage graphique
kml(myCld3,,1,print.traj=TRUE)

# Sans affichage
kml(myCld3)



#####################
### Exporter les rsultats

### Avec choice
choice(myCld2)
choice(myCld3)

### Directement
# Les trajectoires
myCld2["traj"]

# Les partitions
myCld2["clusters"]

# Les partitions avec 3 groupes
myCld2["clusters"][[3]]

# La deuxime partitions avec 3 groupes
myCld2["clusters"][[3]][[2]]

# Les clusters de la deuxime partitions avec 3 groupes
myCld2["clusters"][[3]][[2]]["clusters"]




##############################################
###                 KmL3D                  ###
##############################################

#####################
### Charger le package
# (ouvrir une nouvelle session R)
library(kml3d)

### Prparer les donnes
data4 <- read.csv2("myLongData4.csv")
myCld4 <- as.cld(data4,timeDataFrame=list(jnsptwii=2:12,jnspnp=13:23))


#####################
### Clusteriser les donnes

kml(myCld4,,1)
plot3d(myCld4)
plot3d(myCld4,paramTraj=parTraj(type="n"))

#####################
### Exporter les rsultats

choice(myCld4)
